@@ -1,5 +1,8 @@
 #' @title Get jobs (here: experiments) from registry by id.
 #'
+#' @description
+#' Constructs an \code{\link{Experiment}} for each job id provided.
+#'
 #' @param reg [\code{\link{ExperimentRegistry}}]\cr
 #'   Registry.
 #' @param ids [\code{integer}]\cr
@@ -14,6 +17,6 @@
 #' @export
 getJobs.ExperimentRegistry = function(reg, ids, check.ids = TRUE) {
   if (!missing(ids) && check.ids)
-    ids = BatchJobs:::checkIds(reg, ids)
+    ids = checkIds(reg, ids)
   dbGetJobs(reg, ids)
 }
