@@ -11,7 +11,6 @@
 #'   \item{Wiki:}{\url{https://github.com/tudo-r/BatchExperiments/wiki}}
 #' }
 #'
-#' @docType package
 #' @name BatchExperiments
 #' @import checkmate
 #' @import BBmisc
@@ -21,7 +20,7 @@
 #' @import data.table
 #' @importFrom stats setNames na.omit
 #' @importFrom utils head capture.output packageVersion
-NULL
+"_PACKAGE"
 
 .onLoad <- function(libname, pkgname) {
   backports::import(pkgname)
